//	StandardPhilStatusbar.h - Standard statusbar Component for Phil.
//	--------------------------------------------------------------------------
//	This file is part of 'Phil', a very simple file manager/browser for the
//	JUCE library.
//	Copyright (C) 2005-2006  Niall Moody
//	
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//	
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//	
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//	
//	--------------------------------------------------------------------------

#ifndef STANDARDPHILSTATUSBAR_H_
#define STANDARDPHILSTATUSBAR_H_

class Phil;

///	Standard statusbar Component for Phil.
/*!
	Displays the full path to the currently-displayed directory, as well as
	the size of the currently-highlighted file or (if nothing's selected)
	the number of files/directories in the currently-displayed directory.
 */
class StandardPhilStatusbar : public Component,
							  public ChangeListener
{
  public:
	///	Constructor.
	/*!
		\param parentComponent Pointer to the Phil Component which this is
		attached to.
	 */
	StandardPhilStatusbar(Phil *parentComponent);
	///	Destructor.
	~StandardPhilStatusbar();

	///	Used to place and size the Labels correctly.
	void resized();
	///	So we get informed when the current directory changes etc.
	void changeListenerCallback(void *objectThatHasChanged);

	juce_UseDebuggingNewOperator
  private:
	///	Displays the full path of the currently-displayed directory.
	Label *pathLabel;
	///	Displays different things depending on the context.
	/*!
		Displays either the size of the currently-selected file, or the
		number of files/directories in the currently-displayed directory.  If
		a directory is selected, it'll display the number of files/directories
		it contains.
	 */
	Label *miscLabel;

	///	Pointer to the parent Phil Component.
	Phil *parent;
};

#endif
