//	XYPad.h - Simple x-y pad widget.
//	----------------------------------------------------------------------------
//	This file is part of Mouse To OSC, a simple OSC-outputting program.
//	Copyright (c) 2006 Niall Moody.
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//	----------------------------------------------------------------------------

#ifndef XYPAD_H_
#define XYPAD_H_

///	Simple x-y pad widget.
class XYPad : public Component,
			 public ChangeBroadcaster,
			 public Timer
{
  public:
	///	Constructor.
	XYPad();
	///	Destructor.
	~XYPad();

	///	Used to draw the widget.
	void paint(Graphics& g);

	///	Called when the user clicks on the pad.
	void mouseDown(const MouseEvent& e);
	///	Used to determine when to highlight the control pad.
	void mouseMove(const MouseEvent& e);
	///	Called when the user drags on the pad.
	void mouseDrag(const MouseEvent& e);
	///	Called when the user clicks on the pad.
	void mouseUp(const MouseEvent& e);

	///	Used to update the pad position.
	void timerCallback();

	///	Returns the x position of the pad control.
	/*!
		This is normalised to 0->1.
	 */
	float getXVal() const {return ((float)xPos/(float)(getWidth()-10));};
	///	Returns the y position of the pad control.
	/*!
		This is normalised to 0->1.
	 */
	float getYVal() const {return ((float)yPos/(float)(getHeight()-10));};

	///	Sets the x position of the pad control.
	/*!
		This should be normalised to 0->1.
	 */
	void setXVal(float val);
	///	Sets the y position of the pad control.
	/*!
		This should be normalised to 0->1.
	 */
	void setYVal(float val);
	///	Sets x and y positions of the pad control.
	/*!
		This should be normalised to 0->1.
	 */
	void setXYVal(float xVal, float yVal);

    juce_UseDebuggingNewOperator
  private:
	///	The x position of the pad control.
	int xPos;
	///	The y position of the pad control.
	int yPos;

	///	Whether the user is currently dragging the pad control or not.
	bool draggingPad;
	///	Whether to draw the control pad highlighted or not.
	bool highlightPad;
};

#endif
